import { PrimaryGeneratedColumn, Column, OneToMany } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsString,
} from "class-validator";
import { GroupContact } from "./GroupContact";
import { Runner } from "./Runner";

/**
 * Defines the runnerGroup interface.
*/
export abstract class RunnerGroup {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  /**
   * The group's first name.
   */
  @Column()
  @IsNotEmpty()
  @IsString()
  name: string;

  /**
   * The group's contact.
   * Optional
   */
  @Column()
  @IsOptional()
  //TODO: Relationship
  contact?: GroupContact;

  /**
   * Used to link runners to a runner group.
   */
  @OneToMany(() => Runner, runner => runner.group)
  runners: Runner[];
}